---
myst:
  html_meta:
    "description": "Overview of the Plone distribution API methods"
    "property=og:description": "Overview of the Plone distribution API methods"
    "property=og:title": "Plone distribution API methods and descriptions"
    "keywords": "Plone, API, methods, development"
---

```{eval-rst}
.. currentmodule:: plone.distribution
```

# API methods and descriptions

```{toctree}
:maxdepth: 1
:hidden: true

distribution
site
```


## `api.distribution`

```{eval-rst}
.. autosummary::

    api.distribution.get
    api.distribution.get_distributions
    api.distribution.get_registry
```


## `api.site`

```{eval-rst}
.. autosummary::

    api.site.get_sites
    api.site.create
```
